# Public Domain

If an "intellectual work" (a song, a book, a computer program, ...) is in the public domain (PD), it has no "owner", meaning no one has any exclusive rights (such as [copyright](copyright.md) or [patent](patent.md)) over the work, no one can dictate how and by whom such work can be used and so anyone can basically do anything with such work (anything that's not otherwise illegal of course).

[LRS](lrs.md) highly supports public domain and recommends programmers and artists put their works in the public domain using [waivers](waiver.md) such as [CC0](cc0.md).

Public domain is the ultimate form of freedom in the creative world. In public domain the creativity of people is not restricted. Anyone can study, remix, share and improve public domain works in any way, without a fear of being legally bullied by someone else.

Public domain is NOT the same thing as [free (as in freedom) software](free_software.md), [free culture](free_culture.md) or freeware (gratis, free as in beer) software. The differences are these:

- Unlike public domain, **[free software](free_software.md) and [free cultural](free_culture.md) works are usually still "owned" by someone**, they just try to relax the rules and make them less oppressive. A public domain work is completely unlimited and belongs to everyone and no one, while free software/culture may still require and legally enforce certain freedom-compatible conditions such as giving credit to the author or [copyleft](copyleft.md).
- **Public domain software is not always [free software](free_software.md)** -- PD software is free (as in freedom) only if its source code is available and also in the public domain (without source code freedoms 1 and 2 in the definition of free software are violated).
- **Freeware/gratis just means available for no price**, very often under specific restrictive conditions such as "for personal use" only and without the access to the source code. Public domain is not only gratis but also without any legal limitations on use.

## Which works are in the Public Domain?

This is not a trivial question, firstly because the term *public domain* is not clearly defined: the definition varies by each country's laws, and secondly because it is non-trivial and sometimes very difficult to assess the legal status of a work.

Corporations and [capitalism](capitalism.md) are highly hostile towards public domain and try to destroy it, make it effectively non-existing, as to eliminate "free" works competing with the consumerist creations of the industry. Over many years they have pushes towards creating laws that make it extremely difficult and rare for works to fall into public domain.

Sadly due to these shitty laws most works created in latest decades are NOT in the public domain because of the [copyright](copyright.md) [cancer](cancer.md): copyright is granted automatically, without any registration or fee, to the author of any shitty artistic creation, and its term lasts mostly for **the whole life of the author plus 70 years!** In some countries this is life + 100 years. In the US, copyright lasts 96 years from the publication of the work (every January 1st there is so called public domain day celebrating new works entering the US public domain). In some countries it is not even possible to legally waive (give up) one's copyright. And to make matters worse, copyright isn't the only possible restriction of an intellectual work, there are also [patents](patent.md), [trademarks](trademark.md) and other kinds of [intellectual property](intellectual_property.md).

Another bad news is that works in a **"weak" public domain**, i.e. most recent PD works or works that entered PD by some obscure little law, may as well stop being PD by introducing some shitty retroactive law (which has happened). So one may not be feeling completely safe going crazy by utilizing some recent PD works.

We therefore devise the term **safe/strong public domain**. Under this we include works that are pretty safely PD more or less world-wide, even considering possible changes in laws etc. Let us include these works:

- Works published at least 100 years ago whose author probably died at least 70 years ago.
- Works **clearly and properly** marked by a reliable PD [waiver](waiver.md) such as [CC0](cc0.md). However an extra effort needs to be taken to assure that the work e.g. isn't a derivative work of copyrighted work, or that patents are waived with software.
- Works that under any "reasonable" law can not be covered by "intellectual property", e.g. math equations, colors etc.

[Creative commons](creative_commons.md) has created a **public domain mark** that helps mark and find works that should be in a world-wide public domain (this is not a waiver though, it is basically only used as a metadata for very old works to be better searchable).

## How to Create Public Domain Works

If you want to create a PD work (which you should), then generally in that work **you must not use any non-public domain work**. So, for example, you can NOT create a public domain fan fiction story about Harry Potter because Harry Potter and his universe is copyrighted. Similarly you can't just use randomly googled images in a game you created because the images are most likely copyrighted. Small and obscure exceptions (fonts, freedom of panorama, ...) to this may exist in laws but it's never good to rely on them, it's best to keep it safe and simply avoid utilizing anything non-PD within your works.

Also you can NOT rely on [fair use](fair_use.md)! Even though you could lawfully use someone else's copyrighted work under fair use, inclusion of such material would, by the fair use rules, limit what other would be able to do with your work, making it restricted and therefore not public domain.

So you can only use your own original creations and other public domain works within your PD work. Here you should highly prefer your own creations because that is legally the safest, no one can ever challenge your right to reuse your own creation, but there is a low but considerable chance that someone else's PD work isn't actually PD or will seize to be PD by some retroactive law change. So when it only takes a small effort to e.g. photograph your own textures for a game instead of using someone else's PD textures, choose to use your own.

{ NOTE: The above is kind of arguing for reinventing wheels which goes a little bit against our philosophy or remixing and information sharing, but we are forced to do this by the system. We are forced to reinvent wheel to ensure that users of our works can't be legally bullied. ~drummyfish }

In cases where you DO reuse other PD works, try to minimize their number and try to make sure they belong to the actual **safe** public domain (see above). This again minimizes legal risk and additionally makes it easy to document and prove the sources.

As a next step make sure you clearly **document** your work and the sources you use. This means you write down where all the works contained in your work come from, e.g. in your [readme](read_me.md). Explicitly mention which things you have created yourself (*"I, ..., have created everything myself except for X, Y and Z"*) and which things come from other people and where you have found them. It is great to also archive the proofs of the third party source being public domain (e.g. use the [Internet Archive](internet_archive.md) to snapshot the page with a PD texture you've found).

Finally you need to actually release your work into the public domain. It must be stressed that it is NOT enough to write *"my work is public domain"*, this is simply legally insufficient (and in many countries you can't even put your work into public domain which is why you need a more sophisticated tool). You need to use a public domain [waiver](waiver.md) (similar to a [license](license.md)) which you just put alongside your work (e.g. into the `LICENSE` file), plus it is also good to explicitly write (e.g. in your readme) a sentence such as *"I, ..., release this work into public domain under CC0 1.0 (link)"*. Currently the best waiver you can use is [Creative Commons Zero](cc0.md) (CC0) which is what we recommend. However note that CC0 only waives copyright and not other things like [trademarks](trademark.md) or [patents](patent.md), so e.g. for [software](software.md) you might need to add an extra waiver of these things as well.

For an example of a project project properly released into public domain see the repository of our [LRS](lrs.md) game [Anarch](anarch.md).

## Where to Find Public Domain Works

TODO